@@ -4,12 +4,6 @@ dicom2nifti
 
 @author: abrys
 """
-
-from __future__ import print_function
-import dicom2nifti.patch_pydicom_encodings
-
-dicom2nifti.patch_pydicom_encodings.apply()
-
 import os
 import traceback
 
@@ -23,7 +17,7 @@ from pydicom.tag import Tag
 import dicom2nifti.common as common
 import dicom2nifti.settings as settings
 import dicom2nifti.convert_generic as convert_generic
-from dicom2nifti.exceptions import ConversionError
+from dicom2nifti.exceptions import ConversionError, ConversionValidationError
 
 pydicom_config.enforce_valid_values = False
 logger = logging.getLogger(__name__)
@@ -41,6 +35,19 @@ def dicom_to_nifti(dicom_input, output_file=None):
 
     assert common.is_philips(dicom_input)
 
+    # remove duplicate slices based on position and data
+    dicom_input = convert_generic.remove_duplicate_slices(dicom_input)
+
+    # remove localizers based on image type
+    dicom_input = convert_generic.remove_localizers_by_imagetype(dicom_input)
+
+    # remove_localizers based on image orientation (only valid if slicecount is validated)
+    dicom_input = convert_generic.remove_localizers_by_orientation(dicom_input)
+
+    # if no dicoms remain raise exception
+    if not dicom_input:
+        raise ConversionValidationError('TOO_FEW_SLICES/LOCALIZER')
+
     if common.is_multiframe_dicom(dicom_input):
         _assert_explicit_vr(dicom_input)
         logger.info('Found multiframe dicom')
@@ -233,7 +240,7 @@ def _multiframe_to_nifti(dicom_input, output_file):
     logger.info('Creating nifti')
 
     # Convert to nifti
-    nii_image = nibabel.Nifti1Image(full_block, affine)
+    nii_image = nibabel.Nifti1Image(full_block.squeeze(), affine)
     timing_parameters = multiframe_dicom.SharedFunctionalGroupsSequence[0].MRTimingAndRelatedParametersSequence[0]
     first_frame = multiframe_dicom[Tag(0x5200, 0x9230)][0]
     common.set_tr_te(nii_image, float(timing_parameters.RepetitionTime),
@@ -283,7 +290,7 @@ def _singleframe_to_nifti(grouped_dicoms, output_file):
 
     logger.info('Creating nifti')
     # Convert to nifti
-    nii_image = nibabel.Nifti1Image(full_block, affine)
+    nii_image = nibabel.Nifti1Image(full_block.squeeze(), affine)
     common.set_tr_te(nii_image, float(grouped_dicoms[0][0].RepetitionTime), float(grouped_dicoms[0][0].EchoTime))
 
     if output_file is not None:
@@ -559,7 +566,7 @@ def _fix_diffusion_images(bvals, bvecs, nifti, nifti_file):
     bvecs = bvecs[:-1]
 
     # remove last elements from the nifti
-    new_nifti = nibabel.Nifti1Image(nifti.get_data()[:, :, :, :-1], nifti.affine)
+    new_nifti = nibabel.Nifti1Image(common.get_nifti_data(nifti)[:, :, :, :-1].squeeze(), nifti.affine)
     new_nifti.to_filename(nifti_file)
 
     return new_nifti, bvals, bvecs
